# -*- coding: utf8 -*-
from __future__ import print_function
import os

from sqlibrist.helpers import get_engine, get_config


def status(config):
    """
    1. get applied migrations
    2. get all migrations
    3. check unapplied migrations
    """

    engine = get_engine(config)

    applied_migrations = {m[0] for m in engine.get_applied_migrations()}
    all_migrations = sorted(os.listdir('migrations/'))
    for i, migration in enumerate(all_migrations):
        if migration in applied_migrations:
            print('Migration %s - applied' % migration)
        else:
            print('Migration %s - NOT applied' % migration)


def status_command(args):
    return status(config=get_config(args))



# -*- coding: utf8 -*-
from __future__ import print_function
import difflib

from sqlibrist.helpers import get_last_schema, get_current_schema, \
    compare_schemas


def diff(verbose):
    last_schema = get_last_schema()

    current_schema = get_current_schema()

    added, removed, changed = compare_schemas(last_schema, current_schema)

    if any((added, removed, changed)):
        if added:
            print('New items:')
            for item in added:
                print('  %s' % item)

        if removed:
            print('Removed items:')
            for item in removed:
                print('  %s' % item)

        if changed:
            print('Changed items:')
            for item in changed:
                print('  %s' % item)
                if verbose:
                    _diff = difflib.unified_diff(last_schema[item]['up'],
                                                 current_schema[item]['up'])
                    print('\n'.join(_diff))

    else:
        print('No changes')


def diff_command(args):
    return diff(verbose=args.verbose)



# -*- coding: utf8 -*-
VERSION = '0.0.6'


from sqlibrist.helpers import SqlibristException, handle_exception, \
    get_command_parser


def main():
    parser = get_command_parser()
    args = parser.parse_args()

    try:
        args.func(args)
    except SqlibristException as e:
        handle_exception(e)


if __name__ == '__main__':
    main()


# -*- coding: utf8 -*-
from __future__ import print_function

from sqlibrist.helpers import get_config, get_engine


def initdb(config):
    engine = get_engine(config)

    print('Creating db...')
    engine.create_migrations_table()
    print('Done.')


def initdb_command(args):
    initdb(get_config(args))



# -*- coding: utf8 -*-
import sqlibrist
import os
from setuptools import setup

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='sqlibrist',
    version=sqlibrist.VERSION,
    packages=['sqlibrist', 'django_sqlibrist'],
    include_package_data=True,
    license='MIT License',
    description='Simple tool for managing DB structure, automating patch '
                'creation for DB structure migration.',
    long_description=README,
    url='https://github.com/condograde/sqlibrist',
    author='Serj Zavadsky',
    author_email='fevral13@gmail.com',
    install_requires=['PyYAML'],
    classifiers=[
        'Environment :: Web Environment',
        'Environment :: Console',
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Intended Audience :: System Administrators',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Database',
        'Topic :: Database :: Database Engines/Servers',
        'Topic :: Utilities',
    ],
    keywords='sqlibrist, db structure, sql, schema migration',
    entry_points={
        'console_scripts': [
            'sqlibrist=sqlibrist:main'
        ]
    }
)
